# Example Markdown File

This is a single sentence.

This is the first sentence.
This is the second sentence.

Another single sentence.

Sentence one.
Sentence two.
Sentence three.

## Subheading

This is a single sentence under a subheading.

This is the first sentence under a subheading.
This is the second sentence under a subheading.

- This is a single sentence in a list item.
- This is the first sentence in a list item. This is the second sentence in a list item.

> This is a single sentence in a blockquote.
> This is the first sentence in a blockquote.
This is the second sentence in a blockquote.

1. This is a single sentence in an ordered list.
1. This is the first sentence in an ordered list. This is the second sentence in an ordered list.

**Bold text with a single sentence.**

**Bold text with the first sentence.
Bold text with the second sentence.**

*Italic text with a single sentence.*

*Italic text with the first sentence.
Italic text with the second sentence.*

`Inline code with a single sentence.`

`Inline code with the first sentence.
Inline code with the second sentence.`
